"""
	Licensed Materials - Property of IBM Corp. 
IBM Rational Build Forge 
(c) Copyright IBM Corporation 2005, 2009. All Rights Reserved.   

U.S. Government Users Restricted Rights - Use, duplication or disclosure restricted by 
GSA ADP Schedule Contract with IBM Corp. 

	
	File name: SystemUtils.py
	
	Contains utility methods for working with the components in this system
"""

############## CLASS :: _SystemUtils #####################
# This class provides utility methods for                #
# working with the modules in this system                #
#                                                        #
##########################################################


from Logger import _Logger
import re
from    java.util import Properties
from    java.util import Map
from    java.io import FileInputStream
from    java.io import File

import Globals
import java
newline = java.lang.System.getProperty("line.separator")

class _SystemUtils:

	def __init__(self):
		self.LOGGER = _Logger("SystemUtils")
	#endDef
	
	############### getopt() ##############################
	# Tries to implement unix style getops... options are #
	# separated by a ';' and if a ':' follows then it     #
	# requires an argument... The args are placed into a  #
	# jython-dictionary (Hashtable [key,value pair]       #
	#######################################################
	def getopt(self, args, rules):
		self.LOGGER.traceEnter([args, rules])
		if (isinstance(args, "string".__class__)):
			self.LOGGER.debug("args supplied is a string, converting to a list")
			#convert to a list by space
			args = args.split()
		#endIf
		ruleArgs = {}
		for rule in rules.split(';'):
			if (rule.endswith(':')):
				#rule = '-' + rule.replace( ':','' )
				rule = rule.replace(':', '')
				ruleArgs[rule] = 1
			else:
				#rule = "-" + rule
				ruleArgs[rule] = 0
			#endif
		#endFor
	
		# Now lets walk our args
		num=0
		while num < len(args):
			if (args[num].startswith('-')):
				opt = args[num][1:len(args[num])]
				if ruleArgs.has_key(opt):
					if (ruleArgs[opt] == 1):
						ruleArgs[ opt ] = args[ num + 1]
						num += 1
					else:
						ruleArgs[opt] = 1
					#endIf
				else:
					# raise NameError( 'Illegal getopt argument exception. Unknown argument: ' + args[num] )
					self.LOGGER.trace("Unknown argument supplied: " + args[num] + " with value: " + args[num + 1])
					num += 1
				#endIf
			else:
				# At this point we assume were done with our args so shift num off 
				# the beginning of the stack and then return
				del args[0:num]
			#endIf
			num += 1
		#endFor
		self.LOGGER.traceExit([ruleArgs, args])
		return ruleArgs, args
	#endDef
        ############ getPropertyDict( path ) ##################
        # Reads in the property file and returns it as a dict #
        #######################################################
        def getPropertyDict(self, path):
                thisDict = {}
                properties=Properties();

                try:
                        properties.load(FileInputStream(path))
                        self.LOGGER.trace("read properties file " + str(path))
                except:
                        print "Cannot read property file %s" % (path)
                        raise Exception("Cannot read property file: " + str(path))
                #endTry

                propEnum = properties.propertyNames()
                propKeys = []
                while (propEnum.hasMoreElements()):
                        key = propEnum.nextElement()
                        propKeys.append(key)
                        thisDict[key] = properties.getProperty(key)
                #endWhile

                for key in propKeys:
                        thisDict[key] = properties.getProperty(key)
                        for subkey in propKeys:
                                thisDict[key] = thisDict[key].replace('${' + subkey + '}', thisDict[subkey])
                        #endFor
                #endFor
                return thisDict
        #endDef

#endClass

## define global singletons
SystemUtils = _SystemUtils()

